betty.gui.text module - Betty 0.4.0a1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.gui.text module

Provide text widgets for the Graphical User Interface.

final class betty.gui.text.Caption

  Bases: `Text`

  Display caption text.

  Parameters:

    text (`str` | `None`)

  __init__(text: str | None = None)
    Parameters:

      text (`str` | `None`)

final class betty.gui.text.Code

  Bases: `Text`

  Display source code as text.

  Parameters:

    text (`str` | `None`)

  __init__(text: str | None = None)
    Parameters:

      text (`str` | `None`)

  setText(a0: str | None) → None
    Parameters:

      a0 (`str` | `None`)

    Return type:

      `None`

class betty.gui.text.Text

  Bases: `QLabel`

  Display plain text.

  Parameters:

    text (`str` | `None`)

  __init__(text: str | None = None)
    Parameters:

      text (`str` | `None`)